import os
import sched
import sys


_BASE_DIR = os.path.dirname(os.path.realpath(__file__))
_BELL_SOUND_PATH = os.path.join(_BASE_DIR, 'assets/bell.wav')
_LONG_DELAY_SECONDS = 1500
_RING_PRIORITY = 1


def _ring():
    os.system(f'aplay -q {_BELL_SOUND_PATH}')


def _run():
    scheduler = sched.scheduler()
    scheduler.enter(_LONG_DELAY_SECONDS, _RING_PRIORITY, _ring)
    scheduler.run()


def main():
    try:
        _run()
    except KeyboardInterrupt:
        sys.exit(1)



#!/usr/bin/env python3
import sys

import setuptools

# Minimum setuptools version required to parse setup.cfg metadata.
_SETUPTOOLS_MIN_VERSION = '30.3'

if setuptools.__version__ < _SETUPTOOLS_MIN_VERSION:
    print(f'Error: setuptools version {_SETUPTOOLS_MIN_VERSION} '
          'or greater is required')
    sys.exit(1)

setuptools.setup()
